=====
Xmask
=====

.. contents:: Table of Contents
    :depth: 4

Build collider from MAD-X model
===============================

.. literalinclude:: generated_code_snippets/build_collider_from_mad_model.py
   :language: python

Install beam-beam interactions
==============================

.. literalinclude:: generated_code_snippets/install_beambeam.py
   :language: python

Set knobs and tune the collider
===============================

.. literalinclude:: generated_code_snippets/knobs_and_tuning.py
   :language: python

Configure beam-beam interactions
================================

.. literalinclude:: generated_code_snippets/configure_beambeam.py
   :language: python
